==> jc-1.4.0.tar.gz: gnu/java/rmi/server/TripleKey.h <==
// class gnu.java.rmi.server.TripleKey

// class file dependencies
// @dep_class e22594e3125eeb44 gnu_java_rmi_server_TripleKey
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_rmi_server_TripleKey_H_
#define _JC_gnu_java_rmi_server_TripleKey_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_rmi_server_TripleKey$sub_refs	_jc_gnu_java_rmi_server_TripleKey$sub_refs;
typedef struct _jc_gnu_java_rmi_server_TripleKey$sub_nonrefs	_jc_gnu_java_rmi_server_TripleKey$sub_nonrefs;
typedef struct _jc_gnu_java_rmi_server_TripleKey$refs	_jc_gnu_java_rmi_server_TripleKey$refs;
typedef struct _jc_gnu_java_rmi_server_TripleKey$nonrefs	_jc_gnu_java_rmi_server_TripleKey$nonrefs;
typedef struct _jc_gnu_java_rmi_server_TripleKey$object	_jc_gnu_java_rmi_server_TripleKey$object;

typedef const struct _jc_gnu_java_rmi_server_TripleKey$vmethods	_jc_gnu_java_rmi_server_TripleKey$vmethods;
typedef const struct _jc_gnu_java_rmi_server_TripleKey$vtable	_jc_gnu_java_rmi_server_TripleKey$vtable;
typedef const struct _jc_gnu_java_rmi_server_TripleKey$vtype	_jc_gnu_java_rmi_server_TripleKey$vtype;

// Constructors
extern void _jc_gnu_java_rmi_server_TripleKey$method$_init$cf54cf7a71c3225e(_jc_env *, struct _jc_gnu_java_rmi_server_TripleKey$object *, struct _jc_java_lang_String$object *, jint, struct _jc_java_lang_Object$object *);

// Virtual methods
extern jboolean _jc_gnu_java_rmi_server_TripleKey$method$equals$8a15e0625571c581(_jc_env *, struct _jc_gnu_java_rmi_server_TripleKey$object *, struct _jc_java_lang_Object$object *);
extern jint _jc_gnu_java_rmi_server_TripleKey$method$hashCode$53152098849316df(_jc_env *, struct _jc_gnu_java_rmi_server_TripleKey$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_rmi_server_TripleKey$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_gnu_java_rmi_server_TripleKey$method_info$hashCode$53152098849316df;

// Virtual methods structure
struct _jc_gnu_java_rmi_server_TripleKey$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_gnu_java_rmi_server_TripleKey$object *, struct _jc_java_lang_Object$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_gnu_java_rmi_server_TripleKey$object *);
};

// Vtable
struct _jc_gnu_java_rmi_server_TripleKey$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_rmi_server_TripleKey$vmethods	gnu_java_rmi_server_TripleKey;
};

// Vtype
struct _jc_gnu_java_rmi_server_TripleKey$vtype {
	_jc_type			type;
	_jc_gnu_java_rmi_server_TripleKey$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_rmi_server_TripleKey$sub_refs {
	struct _jc_java_lang_String$object	*host;
	struct _jc_java_lang_Object$object	*other;
};

// Reference instance fields (object)
struct _jc_gnu_java_rmi_server_TripleKey$refs {
    _jc_gnu_java_rmi_server_TripleKey$sub_refs	gnu_java_rmi_server_TripleKey;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_rmi_server_TripleKey$sub_nonrefs {
	jint	port;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_rmi_server_TripleKey$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_rmi_server_TripleKey$sub_nonrefs	gnu_java_rmi_server_TripleKey;
};

// Object instance structure
struct _jc_gnu_java_rmi_server_TripleKey$object {
	_jc_gnu_java_rmi_server_TripleKey$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_rmi_server_TripleKey$vtype	*vtype;
	_jc_gnu_java_rmi_server_TripleKey$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_rmi_server_TripleKey$vtype _jc_gnu_java_rmi_server_TripleKey$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_rmi_server_TripleKey, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_rmi_server_TripleKey$class_object;

#endif	/* _JC_gnu_java_rmi_server_TripleKey_H_ */

==> jc-1.4.6.tar.gz: gnu/java/rmi/server/TripleKey.h <==
// class gnu.java.rmi.server.TripleKey

// class file dependencies
// @dep_class 3eb21e48301eef5a gnu_java_rmi_server_TripleKey
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_rmi_server_TripleKey_H_
#define _JC_gnu_java_rmi_server_TripleKey_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_rmi_server_TripleKey$sub_refs	_jc_gnu_java_rmi_server_TripleKey$sub_refs;
typedef struct _jc_gnu_java_rmi_server_TripleKey$sub_nonrefs	_jc_gnu_java_rmi_server_TripleKey$sub_nonrefs;
typedef struct _jc_gnu_java_rmi_server_TripleKey$refs	_jc_gnu_java_rmi_server_TripleKey$refs;
typedef struct _jc_gnu_java_rmi_server_TripleKey$nonrefs	_jc_gnu_java_rmi_server_TripleKey$nonrefs;
typedef struct _jc_gnu_java_rmi_server_TripleKey$object	_jc_gnu_java_rmi_server_TripleKey$object;

typedef const struct _jc_gnu_java_rmi_server_TripleKey$vmethods	_jc_gnu_java_rmi_server_TripleKey$vmethods;
typedef const struct _jc_gnu_java_rmi_server_TripleKey$vtable	_jc_gnu_java_rmi_server_TripleKey$vtable;
typedef const struct _jc_gnu_java_rmi_server_TripleKey$vtype	_jc_gnu_java_rmi_server_TripleKey$vtype;

// Constructors
extern void _jc_gnu_java_rmi_server_TripleKey$method$_init$cf54cf7a71c3225e(_jc_env *, struct _jc_gnu_java_rmi_server_TripleKey$object *, struct _jc_java_lang_String$object *, jint, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_gnu_java_rmi_server_TripleKey$method$equals$8a15e0625571c581(_jc_env *, struct _jc_gnu_java_rmi_server_TripleKey$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern jint _jc_gnu_java_rmi_server_TripleKey$method$hashCode$53152098849316df(_jc_env *, struct _jc_gnu_java_rmi_server_TripleKey$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_rmi_server_TripleKey$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_gnu_java_rmi_server_TripleKey$method_info$hashCode$53152098849316df;

// Virtual methods structure
struct _jc_gnu_java_rmi_server_TripleKey$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_gnu_java_rmi_server_TripleKey$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_gnu_java_rmi_server_TripleKey$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_rmi_server_TripleKey$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_rmi_server_TripleKey$vmethods	gnu_java_rmi_server_TripleKey;
};

// Vtype
struct _jc_gnu_java_rmi_server_TripleKey$vtype {
	_jc_type			type;
	_jc_gnu_java_rmi_server_TripleKey$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_rmi_server_TripleKey$sub_refs {
	struct _jc_java_lang_String$object	*host;
	struct _jc_java_lang_Object$object	*other;
};

// Reference instance fields (object)
struct _jc_gnu_java_rmi_server_TripleKey$refs {
    _jc_gnu_java_rmi_server_TripleKey$sub_refs	gnu_java_rmi_server_TripleKey;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_rmi_server_TripleKey$sub_nonrefs {
	jint	port;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_rmi_server_TripleKey$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_rmi_server_TripleKey$sub_nonrefs	gnu_java_rmi_server_TripleKey;
};

// Object instance structure
struct _jc_gnu_java_rmi_server_TripleKey$object {
	_jc_gnu_java_rmi_server_TripleKey$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_rmi_server_TripleKey$vtype	*vtype;
	_jc_gnu_java_rmi_server_TripleKey$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_rmi_server_TripleKey$vtype _jc_gnu_java_rmi_server_TripleKey$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_rmi_server_TripleKey, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_rmi_server_TripleKey$class_object;

#endif	/* _JC_gnu_java_rmi_server_TripleKey_H_ */
